@@ -43,7 +43,7 @@
 
 #include <dump_entry.h>
 
-MODULE_ID("$Id: infocmp.c,v 1.174 2025/04/05 19:14:18 tom Exp $")
+MODULE_ID("$Id: infocmp.c,v 1.177 2025/12/27 22:18:10 tom Exp $")
 
 #ifndef ACTUAL_TIC
 #define ACTUAL_TIC "tic"
@@ -847,7 +847,7 @@ lookup_params(const assoc * table, char *dst, char *src)
 static void
 analyze_string(const char *name, const char *cap, TERMTYPE2 *tp)
 {
-    char buf2[MAX_TERMINFO_LENGTH];
+    char buf2[MAX_TERMINFO_LENGTH + 1];
     const char *sp;
     const assoc *ap;
     int tp_lines = tp->Numbers[2];
@@ -877,7 +877,8 @@ analyze_string(const char *name, const char *cap, TERMTYPE2 *tp)
 	    if (VALID_STRING(cp) &&
 		cp[0] != '\0' &&
 		cp != cap) {
-		len = strlen(cp);
+		if ((len = strlen(cp)) > MAX_TERMINFO_LENGTH)
+		    len = MAX_TERMINFO_LENGTH;
 		_nc_STRNCPY(buf2, sp, len);
 		buf2[len] = '\0';
 
@@ -1241,7 +1242,7 @@ usage(void)
 	,"  -I    use terminfo-names"
 	,"  -K    use termcap-names and BSD syntax"
 	,"  -L    use long names"
-	,"  -R subset (see manpage)"
+	,"  -R subset (see man page)"
 	,"  -T    eliminate size limits (test)"
 	,"  -U    do not post-process entries"
 	,"  -V    print version"
@@ -1935,11 +1936,6 @@ main(int argc, char *argv[])
 
 	    if (directory) {
 #if NCURSES_USE_DATABASE
-#if MIXEDCASE_FILENAMES
-#define LEAF_FMT "%c"
-#else
-#define LEAF_FMT "%02x"
-#endif
 		_nc_SPRINTF(tfile[termcount],
 			    _nc_SLIMIT(sizeof(path))
 			    "%s/" LEAF_FMT "/%s",
